#[non_exhaustive]pub enum CleartextVectorDiscardingRetrievalError<EngineError: Error> {
CleartextCountMismatch,
Engine(EngineError),
}Expand description
An error used with the CleartextVectorDiscardingRetrievalEngine trait.
This type provides a
CleartextVectorDiscardingRetrievalError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CleartextCountMismatch
Generic error: The input and output cleartext count must be the same.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> CleartextVectorDiscardingRetrievalError<EngineError>
impl<EngineError: Error> CleartextVectorDiscardingRetrievalError<EngineError>
Sourcepub fn perform_generic_checks<Value, CleartextVector>(
output: &[Value],
input: &CleartextVector,
) -> Result<(), Self>where
CleartextVector: CleartextVectorEntity,
pub fn perform_generic_checks<Value, CleartextVector>(
output: &[Value],
input: &CleartextVector,
) -> Result<(), Self>where
CleartextVector: CleartextVectorEntity,
Validates the inputs