#[non_exhaustive]pub enum GlweCiphertextDiscardingConversionError<EngineError: Error> {
GlweDimensionMismatch,
PolynomialSizeMismatch,
Engine(EngineError),
}Expand description
An error used with the GlweCiphertextDiscardingConversionEngine trait.
This type provides a
GlweCiphertextDiscardingConversionError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GlweDimensionMismatch
Generic error: The input and output GLWE dimension must be the same.
PolynomialSizeMismatch
Generic error: The input and output polynomial size must be the same.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> GlweCiphertextDiscardingConversionError<EngineError>
impl<EngineError: Error> GlweCiphertextDiscardingConversionError<EngineError>
Sourcepub fn perform_generic_checks<Input, Output>(
output: &Output,
input: &Input,
) -> Result<(), Self>where
Input: GlweCiphertextEntity,
Output: GlweCiphertextEntity,
pub fn perform_generic_checks<Input, Output>(
output: &Output,
input: &Input,
) -> Result<(), Self>where
Input: GlweCiphertextEntity,
Output: GlweCiphertextEntity,
Validates the inputs