GlweCiphertextVectorDiscardingDecryptionError

Enum GlweCiphertextVectorDiscardingDecryptionError 

#[non_exhaustive]
pub enum GlweCiphertextVectorDiscardingDecryptionError<EngineError: Error> { GlweDimensionMismatch, PolynomialSizeMismatch, PlaintextCountMismatch, Engine(EngineError), }
An error used with the GlweCiphertextVectorDiscardingDecryptionEngine trait.

This type provides a GlweCiphertextVectorDiscardingDecryptionError::perform_generic_checks function that does error checking for the general cases, returning an Ok(()) if the inputs are valid, meaning that engine implementors would then only need to check for their own specific errors. Otherwise an Err(..) with the proper error variant is returned.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


GlweDimensionMismatch

Generic error: The GLWE dimensions of the key and the input ciphertext vector must be the same.



PolynomialSizeMismatch

Generic error: The polynomial size of the key and the input ciphertext vector must be the same.



PlaintextCountMismatch

Generic error: The input plaintext vector length and input ciphertext vector capacity (poly size * length) must be the same.



Engine(EngineError)

Specific error to the implementing engine.

Implementations

Source

impl<EngineError: Error> GlweCiphertextVectorDiscardingDecryptionError<EngineError>

pub fn perform_generic_checks<SecretKey, CiphertextVector, PlaintextVector>( key: &SecretKey, output: &PlaintextVector, input: &CiphertextVector, ) -> Result<(), Self>
where SecretKey: GlweSecretKeyEntity, CiphertextVector: GlweCiphertextVectorEntity<KeyDistribution = SecretKey::KeyDistribution>, PlaintextVector: PlaintextVectorEntity,

Validates the inputs