#[non_exhaustive]pub enum GlweCiphertextVectorTrivialEncryptionError<EngineError: Error> {
PlaintextCountMismatch,
Engine(EngineError),
}Expand description
An error used with the GlweCiphertextVectorTrivialEncryptionEngine trait.
This type provides a
GlweCiphertextVectorTrivialEncryptionError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PlaintextCountMismatch
Generic error: The number of ciphertexts must divide the plaintext count of the input vector (the result of this division is the polynomial size).
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> GlweCiphertextVectorTrivialEncryptionError<EngineError>
impl<EngineError: Error> GlweCiphertextVectorTrivialEncryptionError<EngineError>
Sourcepub fn perform_generic_checks<PlaintextVector>(
glwe_ciphertext_count: GlweCiphertextCount,
input: &PlaintextVector,
) -> Result<(), Self>where
PlaintextVector: PlaintextVectorEntity,
pub fn perform_generic_checks<PlaintextVector>(
glwe_ciphertext_count: GlweCiphertextCount,
input: &PlaintextVector,
) -> Result<(), Self>where
PlaintextVector: PlaintextVectorEntity,
Validates the inputs