#[non_exhaustive]pub enum LweCiphertextDiscardingBootstrapError<EngineError: Error> {
InputLweDimensionMismatch,
OutputLweDimensionMismatch,
AccumulatorPolynomialSizeMismatch,
AccumulatorGlweDimensionMismatch,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextDiscardingBootstrapEngine trait.
This type provides a
LweCiphertextDiscardingBootstrapError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InputLweDimensionMismatch
Generic error: The input ciphertext and key LWE dimension must be the same.
OutputLweDimensionMismatch
Generic error: The output ciphertext dimension and key size (dimension * polynomial size) must be the same.
AccumulatorPolynomialSizeMismatch
Generic error: The accumulator and key polynomial sizes must be the same.
AccumulatorGlweDimensionMismatch
Generic error: The accumulator and key GLWE dimensions must be the same.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextDiscardingBootstrapError<EngineError>
impl<EngineError: Error> LweCiphertextDiscardingBootstrapError<EngineError>
Sourcepub fn perform_generic_checks<BootstrapKey, Accumulator, InputCiphertext, OutputCiphertext>(
output: &OutputCiphertext,
input: &InputCiphertext,
acc: &Accumulator,
bsk: &BootstrapKey,
) -> Result<(), Self>where
BootstrapKey: LweBootstrapKeyEntity,
Accumulator: GlweCiphertextEntity<KeyDistribution = BootstrapKey::OutputKeyDistribution>,
InputCiphertext: LweCiphertextEntity<KeyDistribution = BootstrapKey::InputKeyDistribution>,
OutputCiphertext: LweCiphertextEntity<KeyDistribution = BootstrapKey::OutputKeyDistribution>,
pub fn perform_generic_checks<BootstrapKey, Accumulator, InputCiphertext, OutputCiphertext>(
output: &OutputCiphertext,
input: &InputCiphertext,
acc: &Accumulator,
bsk: &BootstrapKey,
) -> Result<(), Self>where
BootstrapKey: LweBootstrapKeyEntity,
Accumulator: GlweCiphertextEntity<KeyDistribution = BootstrapKey::OutputKeyDistribution>,
InputCiphertext: LweCiphertextEntity<KeyDistribution = BootstrapKey::InputKeyDistribution>,
OutputCiphertext: LweCiphertextEntity<KeyDistribution = BootstrapKey::OutputKeyDistribution>,
Validates the inputs