#[non_exhaustive]pub enum LweCiphertextDiscardingStoringError<EngineError: Error> {
LweDimensionMismatch,
IndexTooLarge,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextDiscardingStoringEngine trait.
This type provides a
LweCiphertextDiscardingStoringError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LweDimensionMismatch
Generic error: The input and output LWE dimensions must be the same.
IndexTooLarge
Generic error: The index must not exceed the size of the vector.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextDiscardingStoringError<EngineError>
impl<EngineError: Error> LweCiphertextDiscardingStoringError<EngineError>
Sourcepub fn perform_generic_checks<Ciphertext, CiphertextVector>(
vector: &CiphertextVector,
ciphertext: &Ciphertext,
i: LweCiphertextIndex,
) -> Result<(), Self>where
CiphertextVector: LweCiphertextVectorEntity,
Ciphertext: LweCiphertextEntity<KeyDistribution = CiphertextVector::KeyDistribution>,
pub fn perform_generic_checks<Ciphertext, CiphertextVector>(
vector: &CiphertextVector,
ciphertext: &Ciphertext,
i: LweCiphertextIndex,
) -> Result<(), Self>where
CiphertextVector: LweCiphertextVectorEntity,
Ciphertext: LweCiphertextEntity<KeyDistribution = CiphertextVector::KeyDistribution>,
Validates the inputs