#[non_exhaustive]pub enum LweCiphertextDiscardingSubtractionError<EngineError: Error> {
LweDimensionMismatch,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextDiscardingSubtractionEngine trait.
This type provides a
LweCiphertextDiscardingSubtractionError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LweDimensionMismatch
Generic error: All the ciphertext LWE dimensions must be the same.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextDiscardingSubtractionError<EngineError>
impl<EngineError: Error> LweCiphertextDiscardingSubtractionError<EngineError>
Sourcepub fn perform_generic_checks<InputCiphertext, OutputCiphertext>(
output: &OutputCiphertext,
input_1: &InputCiphertext,
input_2: &InputCiphertext,
) -> Result<(), Self>where
InputCiphertext: LweCiphertextEntity,
OutputCiphertext: LweCiphertextEntity<KeyDistribution = InputCiphertext::KeyDistribution>,
pub fn perform_generic_checks<InputCiphertext, OutputCiphertext>(
output: &OutputCiphertext,
input_1: &InputCiphertext,
input_2: &InputCiphertext,
) -> Result<(), Self>where
InputCiphertext: LweCiphertextEntity,
OutputCiphertext: LweCiphertextEntity<KeyDistribution = InputCiphertext::KeyDistribution>,
Validates the inputs