#[non_exhaustive]pub enum LweCiphertextVectorDiscardingAffineTransformationError<EngineError: Error> {
LweDimensionMismatch,
CleartextCountMismatch,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextVectorDiscardingAffineTransformationEngine trait.
This type provides a
LweCiphertextVectorDiscardingAffineTransformationError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LweDimensionMismatch
Generic error: The output and inputs LWE dimensions must be the same.
CleartextCountMismatch
Generic error: The cleartext vector count and input vector count must be the same.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextVectorDiscardingAffineTransformationError<EngineError>
impl<EngineError: Error> LweCiphertextVectorDiscardingAffineTransformationError<EngineError>
Sourcepub fn perform_generic_checks<CiphertextVector, CleartextVector, OutputCiphertext>(
output: &OutputCiphertext,
inputs: &CiphertextVector,
weights: &CleartextVector,
) -> Result<(), Self>where
OutputCiphertext: LweCiphertextEntity,
CiphertextVector: LweCiphertextVectorEntity<KeyDistribution = OutputCiphertext::KeyDistribution>,
CleartextVector: CleartextVectorEntity,
pub fn perform_generic_checks<CiphertextVector, CleartextVector, OutputCiphertext>(
output: &OutputCiphertext,
inputs: &CiphertextVector,
weights: &CleartextVector,
) -> Result<(), Self>where
OutputCiphertext: LweCiphertextEntity,
CiphertextVector: LweCiphertextVectorEntity<KeyDistribution = OutputCiphertext::KeyDistribution>,
CleartextVector: CleartextVectorEntity,
Validates the inputs