#[non_exhaustive]pub enum LweCiphertextVectorDiscardingKeyswitchError<EngineError: Error> {
InputLweDimensionMismatch,
OutputLweDimensionMismatch,
CiphertextCountMismatch,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextVectorDiscardingKeyswitchEngine trait.
This type provides a
LweCiphertextVectorDiscardingKeyswitchError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InputLweDimensionMismatch
Generic error: The input ciphertext vector and keyswitch key input LWE dimension must be the same.
OutputLweDimensionMismatch
Generic error: The output ciphertext vector and keyswitch key output LWE dimension must be the same.
CiphertextCountMismatch
Generic error: The input and output ciphertexts have different ciphertext counts.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextVectorDiscardingKeyswitchError<EngineError>
impl<EngineError: Error> LweCiphertextVectorDiscardingKeyswitchError<EngineError>
Sourcepub fn perform_generic_checks<KeyswitchKey, InputCiphertextVector, OutputCiphertextVector>(
output: &mut OutputCiphertextVector,
input: &InputCiphertextVector,
ksk: &KeyswitchKey,
) -> Result<(), Self>where
KeyswitchKey: LweKeyswitchKeyEntity,
InputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = KeyswitchKey::InputKeyDistribution>,
OutputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = KeyswitchKey::OutputKeyDistribution>,
pub fn perform_generic_checks<KeyswitchKey, InputCiphertextVector, OutputCiphertextVector>(
output: &mut OutputCiphertextVector,
input: &InputCiphertextVector,
ksk: &KeyswitchKey,
) -> Result<(), Self>where
KeyswitchKey: LweKeyswitchKeyEntity,
InputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = KeyswitchKey::InputKeyDistribution>,
OutputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = KeyswitchKey::OutputKeyDistribution>,
Validates the inputs