#[non_exhaustive]pub enum LweCiphertextVectorDiscardingLoadingError<EngineError: Error> {
LweDimensionMismatch,
UnorderedInputRange,
OutOfVectorInputRange,
UnorderedOutputRange,
OutOfVectorOutputRange,
RangeSizeMismatch,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextVectorDiscardingLoadingEngine trait.
This type provides a
LweCiphertextVectorDiscardingLoadingError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
LweDimensionMismatch
Generic error: The input and output LWE dimension must be the same.
UnorderedInputRange
Generic error: The input range bounds must be ordered.
OutOfVectorInputRange
Generic error: The input vector must contain the input range.
UnorderedOutputRange
Generic error: The output range bound must be ordered.
OutOfVectorOutputRange
Generic error: The output vector must contain the output range.
RangeSizeMismatch
Generic error: The input and output range must have the same size.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextVectorDiscardingLoadingError<EngineError>
impl<EngineError: Error> LweCiphertextVectorDiscardingLoadingError<EngineError>
Sourcepub fn perform_generic_checks<InputCiphertextVector, OutputCiphertextVector>(
output_vector: &OutputCiphertextVector,
input_vector: &InputCiphertextVector,
output_range: LweCiphertextRange,
input_range: LweCiphertextRange,
) -> Result<(), Self>where
InputCiphertextVector: LweCiphertextVectorEntity,
OutputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = InputCiphertextVector::KeyDistribution>,
pub fn perform_generic_checks<InputCiphertextVector, OutputCiphertextVector>(
output_vector: &OutputCiphertextVector,
input_vector: &InputCiphertextVector,
output_range: LweCiphertextRange,
input_range: LweCiphertextRange,
) -> Result<(), Self>where
InputCiphertextVector: LweCiphertextVectorEntity,
OutputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = InputCiphertextVector::KeyDistribution>,
Validates the inputs