#[non_exhaustive]pub enum LweCiphertextVectorDiscardingOppositeError<EngineError: Error> {
LweDimensionMismatch,
CiphertextCountMismatch,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextVectorDiscardingOppositeEngine trait.
This type provides a
LweCiphertextVectorDiscardingOppositeError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LweDimensionMismatch
Generic error: The input and output LWE dimension must be the same.
CiphertextCountMismatch
Generic error: The input and output ciphertext count must be the same.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextVectorDiscardingOppositeError<EngineError>
impl<EngineError: Error> LweCiphertextVectorDiscardingOppositeError<EngineError>
Sourcepub fn perform_generic_checks<InputCiphertextVector, OutputCiphertextVector>(
output: &OutputCiphertextVector,
input: &InputCiphertextVector,
) -> Result<(), Self>where
InputCiphertextVector: LweCiphertextVectorEntity,
OutputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = InputCiphertextVector::KeyDistribution>,
pub fn perform_generic_checks<InputCiphertextVector, OutputCiphertextVector>(
output: &OutputCiphertextVector,
input: &InputCiphertextVector,
) -> Result<(), Self>where
InputCiphertextVector: LweCiphertextVectorEntity,
OutputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = InputCiphertextVector::KeyDistribution>,
Validates the inputs