#[non_exhaustive]pub enum LweCiphertextVectorLoadingError<EngineError: Error> {
UnorderedInputRange,
OutOfVectorInputRange,
Engine(EngineError),
}Expand description
An error used with the LweCiphertextVectorLoadingEngine trait.
This type provides a
LweCiphertextVectorLoadingError::perform_generic_checks
function that does error checking for the general cases, returning an Ok(())
if the inputs are valid, meaning that engine implementors would then only
need to check for their own specific errors.
Otherwise an Err(..) with the proper error variant is returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnorderedInputRange
Generic error: The input range bounds must be ordered.
OutOfVectorInputRange
Generic error: The input vector must contain the input range.
Engine(EngineError)
Specific error to the implementing engine.
Implementations
Sourceimpl<EngineError: Error> LweCiphertextVectorLoadingError<EngineError>
impl<EngineError: Error> LweCiphertextVectorLoadingError<EngineError>
Sourcepub fn perform_generic_checks<CiphertextVector, SubCiphertextVector>(
vector: &CiphertextVector,
range: LweCiphertextRange,
) -> Result<(), Self>where
CiphertextVector: LweCiphertextVectorEntity,
SubCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = CiphertextVector::KeyDistribution>,
pub fn perform_generic_checks<CiphertextVector, SubCiphertextVector>(
vector: &CiphertextVector,
range: LweCiphertextRange,
) -> Result<(), Self>where
CiphertextVector: LweCiphertextVectorEntity,
SubCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = CiphertextVector::KeyDistribution>,
Validates the inputs