GlweCiphertextVectorDiscardingDecryptionEngine

Trait GlweCiphertextVectorDiscardingDecryptionEngine 

pub trait GlweCiphertextVectorDiscardingDecryptionEngine<SecretKey, CiphertextVector, PlaintextVector>: AbstractEngine
where SecretKey: GlweSecretKeyEntity, CiphertextVector: GlweCiphertextVectorEntity<KeyDistribution = SecretKey::KeyDistribution>, PlaintextVector: PlaintextVectorEntity,
{ // Required methods fn discard_decrypt_glwe_ciphertext_vector( &mut self, key: &SecretKey, output: &mut PlaintextVector, input: &CiphertextVector, ) -> Result<(), GlweCiphertextVectorDiscardingDecryptionError<Self::EngineError>>; unsafe fn discard_decrypt_glwe_ciphertext_vector_unchecked( &mut self, key: &SecretKey, output: &mut PlaintextVector, input: &CiphertextVector, ); }
A trait for engines decrypting (discarding) GLWE ciphertext vectors.

Semantics

This discarding operation fills the output plaintext vector
with the piece-wise decryptions of the input GLWE ciphertext vector, under the key secret key.

Formal Definition

Required Methods

fn discard_decrypt_glwe_ciphertext_vector( &mut self, key: &SecretKey, output: &mut PlaintextVector, input: &CiphertextVector, ) -> Result<(), GlweCiphertextVectorDiscardingDecryptionError<Self::EngineError>>

Decrypts a GLWE ciphertext vector .

unsafe fn discard_decrypt_glwe_ciphertext_vector_unchecked( &mut self, key: &SecretKey, output: &mut PlaintextVector, input: &CiphertextVector, )

Unsafely encrypts a GLWE ciphertext vector .

Safety

For the general safety concerns regarding this operation, refer to the different variants of GlweCiphertextVectorDiscardingDecryptionError. For safety concerns specific to an engine, refer to the implementer safety section.

Implementors