GlweCiphertextVectorDiscardingEncryptionEngine

Trait GlweCiphertextVectorDiscardingEncryptionEngine 

pub trait GlweCiphertextVectorDiscardingEncryptionEngine<SecretKey, PlaintextVector, CiphertextVector>: AbstractEngine
where SecretKey: GlweSecretKeyEntity, PlaintextVector: PlaintextVectorEntity, CiphertextVector: GlweCiphertextVectorEntity<KeyDistribution = SecretKey::KeyDistribution>,
{ // Required methods fn discard_encrypt_glwe_ciphertext_vector( &mut self, key: &SecretKey, output: &mut CiphertextVector, input: &PlaintextVector, noise: Variance, ) -> Result<(), GlweCiphertextVectorDiscardingEncryptionError<Self::EngineError>>; unsafe fn discard_encrypt_glwe_ciphertext_vector_unchecked( &mut self, key: &SecretKey, output: &mut CiphertextVector, input: &PlaintextVector, noise: Variance, ); }
A trait for engines encrypting (discarding) GLWE ciphertext vectors.

Semantics

This discarding operation fills the output GLWE ciphertext vector with the piece-wise encryptions of the input plaintext vector, under the key secret key.

Formal Definition

Required Methods

fn discard_encrypt_glwe_ciphertext_vector( &mut self, key: &SecretKey, output: &mut CiphertextVector, input: &PlaintextVector, noise: Variance, ) -> Result<(), GlweCiphertextVectorDiscardingEncryptionError<Self::EngineError>>

Encrypts a GLWE ciphertext vector .

unsafe fn discard_encrypt_glwe_ciphertext_vector_unchecked( &mut self, key: &SecretKey, output: &mut CiphertextVector, input: &PlaintextVector, noise: Variance, )

Unsafely encrypts a GLWE ciphertext vector .

Safety

For the general safety concerns regarding this operation, refer to the different variants of GlweCiphertextVectorDiscardingEncryptionError. For safety concerns specific to an engine, refer to the implementer safety section.

Implementors