LweBootstrapKeyDiscardingConversionEngine

Trait LweBootstrapKeyDiscardingConversionEngine 

pub trait LweBootstrapKeyDiscardingConversionEngine<Input, Output>: AbstractEngine
where Input: LweBootstrapKeyEntity, Output: LweBootstrapKeyEntity<InputKeyDistribution = Input::InputKeyDistribution, OutputKeyDistribution = Input::OutputKeyDistribution>,
{ // Required methods fn discard_convert_lwe_bootstrap_key( &mut self, output: &mut Output, input: &Input, ) -> Result<(), LweBootstrapKeyDiscardingConversionError<Self::EngineError>>; unsafe fn discard_convert_lwe_bootstrap_key_unchecked( &mut self, output: &mut Output, input: &Input, ); }
A trait for engines converting (discarding) LWE bootstrap keys .

Semantics

This discarding operation fills the output LWE bootstrap key with the conversion of the input LWE bootstrap key to a type with a different representation (for instance from cpu to gpu memory).

Formal Definition

Required Methods

fn discard_convert_lwe_bootstrap_key( &mut self, output: &mut Output, input: &Input, ) -> Result<(), LweBootstrapKeyDiscardingConversionError<Self::EngineError>>

Converts a LWE bootstrap key .

unsafe fn discard_convert_lwe_bootstrap_key_unchecked( &mut self, output: &mut Output, input: &Input, )

Unsafely converts a LWE bootstrap key .

Safety

For the general safety concerns regarding this operation, refer to the different variants of LweBootstrapKeyDiscardingConversionError. For safety concerns specific to an engine, refer to the implementer safety section.

Implementors