LweCiphertextDiscardingLoadingEngine

Trait LweCiphertextDiscardingLoadingEngine 

pub trait LweCiphertextDiscardingLoadingEngine<CiphertextVector, Ciphertext>: AbstractEngine
where Ciphertext: LweCiphertextEntity, CiphertextVector: LweCiphertextVectorEntity<KeyDistribution = Ciphertext::KeyDistribution>,
{ // Required methods fn discard_load_lwe_ciphertext( &mut self, ciphertext: &mut Ciphertext, vector: &CiphertextVector, i: LweCiphertextIndex, ) -> Result<(), LweCiphertextDiscardingLoadingError<Self::EngineError>>; unsafe fn discard_load_lwe_ciphertext_unchecked( &mut self, ciphertext: &mut Ciphertext, vector: &CiphertextVector, i: LweCiphertextIndex, ); }
A trait for engines loading (discarding) an LWE ciphertext from a LWE ciphertext vector.

Semantics

This discarding operation fills the ciphertext LWE ciphertext with the ith LWE ciphertext of the vector LWE ciphertext vector.

Formal Definition

Required Methods

fn discard_load_lwe_ciphertext( &mut self, ciphertext: &mut Ciphertext, vector: &CiphertextVector, i: LweCiphertextIndex, ) -> Result<(), LweCiphertextDiscardingLoadingError<Self::EngineError>>

Loads an LWE ciphertext from an LWE ciphertext vector.

unsafe fn discard_load_lwe_ciphertext_unchecked( &mut self, ciphertext: &mut Ciphertext, vector: &CiphertextVector, i: LweCiphertextIndex, )

Unsafely loads an LWE ciphertext from an LWE ciphertext vector.

Safety

For the general safety concerns regarding this operation, refer to the different variants of LweCiphertextDiscardingLoadingError. For safety concerns specific to an engine, refer to the implementer safety section.

Implementors