LweCiphertextVectorConversionEngine

Trait LweCiphertextVectorConversionEngine 

pub trait LweCiphertextVectorConversionEngine<Input, Output>: AbstractEngine{
    // Required methods
    fn convert_lwe_ciphertext_vector(
        &mut self,
        input: &Input,
    ) -> Result<Output, LweCiphertextVectorConversionError<Self::EngineError>>;
    unsafe fn convert_lwe_ciphertext_vector_unchecked(
        &mut self,
        input: &Input,
    ) -> Output;
}
A trait for engines converting LWE ciphertext vectors.

Semantics

This pure operation generates a LWE ciphertext vector containing the conversion of the input LWE ciphertext vector to a type with a different representation (for instance from cpu to gpu memory).

Formal Definition

Required Methods

fn convert_lwe_ciphertext_vector( &mut self, input: &Input, ) -> Result<Output, LweCiphertextVectorConversionError<Self::EngineError>>

Converts a LWE ciphertext vector.

unsafe fn convert_lwe_ciphertext_vector_unchecked( &mut self, input: &Input, ) -> Output

Unsafely converts a LWE ciphertext vector.

Safety

For the general safety concerns regarding this operation, refer to the different variants of LweCiphertextVectorConversionError. For safety concerns specific to an engine, refer to the implementer safety section.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors