LweCiphertextVectorFusingOppositeEngine

Trait LweCiphertextVectorFusingOppositeEngine 

pub trait LweCiphertextVectorFusingOppositeEngine<CiphertextVector>: AbstractEngine
where CiphertextVector: LweCiphertextVectorEntity,
{ // Required methods fn fuse_opp_lwe_ciphertext_vector( &mut self, input: &mut CiphertextVector, ) -> Result<(), LweCiphertextVectorFusingOppositeError<Self::EngineError>>; unsafe fn fuse_opp_lwe_ciphertext_vector_unchecked( &mut self, input: &mut CiphertextVector, ); }
A trait for engines computing the opposite (fusing) LWE ciphertext vectors.

Semantics

This fusing operation computes the opposite of the input LWE ciphertext vector.

Formal Definition

Required Methods

fn fuse_opp_lwe_ciphertext_vector( &mut self, input: &mut CiphertextVector, ) -> Result<(), LweCiphertextVectorFusingOppositeError<Self::EngineError>>

Computes the opposite of an LWE ciphertext vector.

unsafe fn fuse_opp_lwe_ciphertext_vector_unchecked( &mut self, input: &mut CiphertextVector, )

Unsafely computes the opposite of an LWE ciphertext vector.

Safety

For the general safety concerns regarding this operation, refer to the different variants of LweCiphertextVectorFusingOppositeError. For safety concerns specific to an engine, refer to the implementer safety section.

Implementors