LweCiphertextVectorLoadingEngine

Trait LweCiphertextVectorLoadingEngine 

pub trait LweCiphertextVectorLoadingEngine<CiphertextVector, SubCiphertextVector>: AbstractEngine
where CiphertextVector: LweCiphertextVectorEntity, SubCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = CiphertextVector::KeyDistribution>,
{ // Required methods fn load_lwe_ciphertext_vector( &mut self, vector: &CiphertextVector, range: LweCiphertextRange, ) -> Result<SubCiphertextVector, LweCiphertextVectorLoadingError<Self::EngineError>>; unsafe fn load_lwe_ciphertext_vector_unchecked( &mut self, vector: &CiphertextVector, range: LweCiphertextRange, ) -> SubCiphertextVector; }
A trait for engines loading a sub LWE ciphertext vector from another one.

Semantics

This pure operation generates an LWE ciphertext vector containing a piece of the vector LWE ciphertext vector.

Formal Definition

Required Methods

fn load_lwe_ciphertext_vector( &mut self, vector: &CiphertextVector, range: LweCiphertextRange, ) -> Result<SubCiphertextVector, LweCiphertextVectorLoadingError<Self::EngineError>>

Loads a subpart of an LWE ciphertext vector.

unsafe fn load_lwe_ciphertext_vector_unchecked( &mut self, vector: &CiphertextVector, range: LweCiphertextRange, ) -> SubCiphertextVector

Unsafely loads a subpart of an LWE ciphertext vector.

Safety

For the general safety concerns regarding this operation, refer to the different variants of LweCiphertextVectorLoadingError. For safety concerns specific to an engine, refer to the implementer safety section.

Implementors