pub struct GgswCiphertextCount(pub usize);Expand description
The number of ciphertexts in a ggsw ciphertext list.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for GgswCiphertextCount
impl Clone for GgswCiphertextCount
Sourcefn clone(&self) -> GgswCiphertextCount
fn clone(&self) -> GgswCiphertextCount
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GgswCiphertextCount
impl Debug for GgswCiphertextCount
Sourceimpl<'de> Deserialize<'de> for GgswCiphertextCount
impl<'de> Deserialize<'de> for GgswCiphertextCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GgswCiphertextCount
impl PartialEq for GgswCiphertextCount
Sourcefn eq(&self, other: &GgswCiphertextCount) -> bool
fn eq(&self, other: &GgswCiphertextCount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GgswCiphertextCount
impl Serialize for GgswCiphertextCount
impl Copy for GgswCiphertextCount
impl Eq for GgswCiphertextCount
impl StructuralPartialEq for GgswCiphertextCount