pub struct GswCiphertextCount(pub usize);Expand description
The number of ciphertexts in a gsw ciphertext list.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for GswCiphertextCount
impl Clone for GswCiphertextCount
Sourcefn clone(&self) -> GswCiphertextCount
fn clone(&self) -> GswCiphertextCount
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GswCiphertextCount
impl Debug for GswCiphertextCount
Sourceimpl<'de> Deserialize<'de> for GswCiphertextCount
impl<'de> Deserialize<'de> for GswCiphertextCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GswCiphertextCount
impl PartialEq for GswCiphertextCount
Sourcefn eq(&self, other: &GswCiphertextCount) -> bool
fn eq(&self, other: &GswCiphertextCount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GswCiphertextCount
impl Serialize for GswCiphertextCount
impl Copy for GswCiphertextCount
impl Eq for GswCiphertextCount
impl StructuralPartialEq for GswCiphertextCount