pub struct LweCiphertextIndex(pub usize);Expand description
The index of a ciphertext in an lwe ciphertext list.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for LweCiphertextIndex
impl Clone for LweCiphertextIndex
Sourcefn clone(&self) -> LweCiphertextIndex
fn clone(&self) -> LweCiphertextIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LweCiphertextIndex
impl Debug for LweCiphertextIndex
Sourceimpl<'de> Deserialize<'de> for LweCiphertextIndex
impl<'de> Deserialize<'de> for LweCiphertextIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LweCiphertextIndex
impl PartialEq for LweCiphertextIndex
Sourcefn eq(&self, other: &LweCiphertextIndex) -> bool
fn eq(&self, other: &LweCiphertextIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LweCiphertextIndex
impl Serialize for LweCiphertextIndex
impl Copy for LweCiphertextIndex
impl Eq for LweCiphertextIndex
impl StructuralPartialEq for LweCiphertextIndex