pub struct ModulusSwitchOffset(pub usize);Expand description
The number of MSB shifted in a Modulus Switch.
When performing a Modulus Switch, this type represents the number of MSB that will be discarded.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for ModulusSwitchOffset
impl Clone for ModulusSwitchOffset
Sourcefn clone(&self) -> ModulusSwitchOffset
fn clone(&self) -> ModulusSwitchOffset
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModulusSwitchOffset
impl Debug for ModulusSwitchOffset
Sourceimpl<'de> Deserialize<'de> for ModulusSwitchOffset
impl<'de> Deserialize<'de> for ModulusSwitchOffset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ModulusSwitchOffset
impl PartialEq for ModulusSwitchOffset
Sourcefn eq(&self, other: &ModulusSwitchOffset) -> bool
fn eq(&self, other: &ModulusSwitchOffset) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModulusSwitchOffset
impl Serialize for ModulusSwitchOffset
impl Copy for ModulusSwitchOffset
impl Eq for ModulusSwitchOffset
impl StructuralPartialEq for ModulusSwitchOffset