pub struct PolynomialCount(pub usize);Expand description
The number of polynomials in a polynomial list.
Assuming a polynomial list, this return the number of polynomials.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for PolynomialCount
impl Clone for PolynomialCount
Sourcefn clone(&self) -> PolynomialCount
fn clone(&self) -> PolynomialCount
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolynomialCount
impl Debug for PolynomialCount
Sourceimpl<'de> Deserialize<'de> for PolynomialCount
impl<'de> Deserialize<'de> for PolynomialCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PolynomialCount
impl PartialEq for PolynomialCount
Sourcefn eq(&self, other: &PolynomialCount) -> bool
fn eq(&self, other: &PolynomialCount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PolynomialCount
impl Serialize for PolynomialCount
impl Copy for PolynomialCount
impl Eq for PolynomialCount
impl StructuralPartialEq for PolynomialCount