LweCiphertextVectorGlweCiphertextDiscardingFunctionalPackingKeyswitchError

Enum LweCiphertextVectorGlweCiphertextDiscardingFunctionalPackingKeyswitchError 

#[non_exhaustive]
pub enum LweCiphertextVectorGlweCiphertextDiscardingFunctionalPackingKeyswitchError<EngineError: Error> { InputLweDimensionMismatch, OutputGlweDimensionMismatch, OutputPolynomialSizeMismatch, CiphertextCountMismatch, Engine(EngineError), }
An error used with the LweCiphertextVectorGlweCiphertextDiscardingFunctionalPackingKeyswitchEngine trait.

This type provides a LweCiphertextVectorGlweCiphertextDiscardingFunctionalPackingKeyswitchError::perform_generic_checks function that does error checking for the general cases, returning an Ok(()) if the inputs are valid, meaning that engine implementors would then only need to check for their own specific errors. Otherwise an Err(..) with the proper error variant is returned.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InputLweDimensionMismatch

Generic error: The input ciphertext vector and input functional packing keyswitch key LWE dimension must be the same.



OutputGlweDimensionMismatch

Generic error: The output ciphertext vector and functional packing keyswitch key output GLWE dimensions must be the same.



OutputPolynomialSizeMismatch

Generic error: The output ciphertext vector and functional packing keyswitch key polynomial sizes must be the same.



CiphertextCountMismatch

Generic error: The input ciphertext count is bigger than the output polynomial size.



Engine(EngineError)

Specific error to the implementing engine.

Implementations

Source

impl<EngineError: Error> LweCiphertextVectorGlweCiphertextDiscardingFunctionalPackingKeyswitchError<EngineError>

pub fn perform_generic_checks<FunctionalPackingKeyswitchKey, InputCiphertextVector, OutputCiphertext>( output: &mut OutputCiphertext, input: &InputCiphertextVector, ksk: &FunctionalPackingKeyswitchKey, ) -> Result<(), Self>
where FunctionalPackingKeyswitchKey: FunctionalPackingKeyswitchKeyEntity, InputCiphertextVector: LweCiphertextVectorEntity<KeyDistribution = FunctionalPackingKeyswitchKey::InputKeyDistribution>, OutputCiphertext: GlweCiphertextEntity<KeyDistribution = FunctionalPackingKeyswitchKey::OutputKeyDistribution>,

Validates the inputs