pub trait LweCiphertextDiscardingConversionEngine<Input, Output>: AbstractEnginewhere
Input: LweCiphertextEntity,
Output: LweCiphertextEntity,{
// Required methods
fn discard_convert_lwe_ciphertext(
&mut self,
output: &mut Output,
input: &Input,
) -> Result<(), LweCiphertextDiscardingConversionError<Self::EngineError>>;
unsafe fn discard_convert_lwe_ciphertext_unchecked(
&mut self,
output: &mut Output,
input: &Input,
);
}Expand description
A trait for engines converting (discarding) LWE ciphertexts .
Semantics
This discarding operation fills the output LWE ciphertext with
the conversion of the input LWE ciphertext to a type with a different representation (for
instance from cpu to gpu memory).
Formal Definition
Required Methods
Sourcefn discard_convert_lwe_ciphertext(
&mut self,
output: &mut Output,
input: &Input,
) -> Result<(), LweCiphertextDiscardingConversionError<Self::EngineError>>
fn discard_convert_lwe_ciphertext( &mut self, output: &mut Output, input: &Input, ) -> Result<(), LweCiphertextDiscardingConversionError<Self::EngineError>>
Converts a LWE ciphertext .
Sourceunsafe fn discard_convert_lwe_ciphertext_unchecked(
&mut self,
output: &mut Output,
input: &Input,
)
unsafe fn discard_convert_lwe_ciphertext_unchecked( &mut self, output: &mut Output, input: &Input, )
Unsafely converts a LWE ciphertext .
Safety
For the general safety concerns regarding this operation, refer to the different variants
of LweCiphertextDiscardingConversionError. For safety concerns specific to an engine,
refer to the implementer safety section.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".